==> jc-1.4.0.tar.gz: java/lang/reflect/InvocationTargetException.h <==
// public class java.lang.reflect.InvocationTargetException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class ae4a2342b31a268d java_lang_reflect_InvocationTargetException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_lang_reflect_InvocationTargetException_H_
#define _JC_java_lang_reflect_InvocationTargetException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_reflect_InvocationTargetException$sub_refs	_jc_java_lang_reflect_InvocationTargetException$sub_refs;
typedef struct _jc_java_lang_reflect_InvocationTargetException$sub_nonrefs	_jc_java_lang_reflect_InvocationTargetException$sub_nonrefs;
typedef struct _jc_java_lang_reflect_InvocationTargetException$refs	_jc_java_lang_reflect_InvocationTargetException$refs;
typedef struct _jc_java_lang_reflect_InvocationTargetException$nonrefs	_jc_java_lang_reflect_InvocationTargetException$nonrefs;
typedef struct _jc_java_lang_reflect_InvocationTargetException$object	_jc_java_lang_reflect_InvocationTargetException$object;

typedef struct _jc_java_lang_reflect_InvocationTargetException$fields_struct	_jc_java_lang_reflect_InvocationTargetException$fields_struct;
typedef const struct _jc_java_lang_reflect_InvocationTargetException$vmethods	_jc_java_lang_reflect_InvocationTargetException$vmethods;
typedef const struct _jc_java_lang_reflect_InvocationTargetException$vtable	_jc_java_lang_reflect_InvocationTargetException$vtable;
typedef const struct _jc_java_lang_reflect_InvocationTargetException$vtype	_jc_java_lang_reflect_InvocationTargetException$vtype;

// Class fields structure
struct _jc_java_lang_reflect_InvocationTargetException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_reflect_InvocationTargetException$fields_struct _jc_java_lang_reflect_InvocationTargetException$class_fields;

// Constructors
extern void _jc_java_lang_reflect_InvocationTargetException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_reflect_InvocationTargetException$object *);
extern void _jc_java_lang_reflect_InvocationTargetException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_lang_reflect_InvocationTargetException$object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_java_lang_reflect_InvocationTargetException$method$_init$3ba429d9416edd46(_jc_env *, struct _jc_java_lang_reflect_InvocationTargetException$object *, struct _jc_java_lang_Throwable$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_reflect_InvocationTargetException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_lang_reflect_InvocationTargetException$object *);
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_reflect_InvocationTargetException$method$getTargetException$53e4eff431eac541(_jc_env *, struct _jc_java_lang_reflect_InvocationTargetException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_reflect_InvocationTargetException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_lang_reflect_InvocationTargetException$method_info$getTargetException$53e4eff431eac541;

// Virtual methods structure
struct _jc_java_lang_reflect_InvocationTargetException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_lang_reflect_InvocationTargetException$object *);
	struct _jc_java_lang_Throwable$object	*(*getTargetException$53e4eff431eac541)(_jc_env *, struct _jc_java_lang_reflect_InvocationTargetException$object *);
};

// Vtable
struct _jc_java_lang_reflect_InvocationTargetException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_reflect_InvocationTargetException$vmethods	java_lang_reflect_InvocationTargetException;
};

// Vtype
struct _jc_java_lang_reflect_InvocationTargetException$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_InvocationTargetException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_InvocationTargetException$sub_refs {
	struct _jc_java_lang_Throwable$object	*target;
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_InvocationTargetException$refs {
    _jc_java_lang_reflect_InvocationTargetException$sub_refs	java_lang_reflect_InvocationTargetException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_InvocationTargetException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_InvocationTargetException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_reflect_InvocationTargetException$sub_nonrefs	java_lang_reflect_InvocationTargetException;
};

// Object instance structure
struct _jc_java_lang_reflect_InvocationTargetException$object {
	_jc_java_lang_reflect_InvocationTargetException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_InvocationTargetException$vtype	*vtype;
	_jc_java_lang_reflect_InvocationTargetException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_InvocationTargetException$vtype _jc_java_lang_reflect_InvocationTargetException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_InvocationTargetException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_InvocationTargetException$class_object;

#endif	/* _JC_java_lang_reflect_InvocationTargetException_H_ */

==> jc-1.4.6.tar.gz: java/lang/reflect/InvocationTargetException.h <==
// public class java.lang.reflect.InvocationTargetException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class ae4a2342b31a268d java_lang_reflect_InvocationTargetException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_lang_reflect_InvocationTargetException_H_
#define _JC_java_lang_reflect_InvocationTargetException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_reflect_InvocationTargetException$sub_refs	_jc_java_lang_reflect_InvocationTargetException$sub_refs;
typedef struct _jc_java_lang_reflect_InvocationTargetException$sub_nonrefs	_jc_java_lang_reflect_InvocationTargetException$sub_nonrefs;
typedef struct _jc_java_lang_reflect_InvocationTargetException$refs	_jc_java_lang_reflect_InvocationTargetException$refs;
typedef struct _jc_java_lang_reflect_InvocationTargetException$nonrefs	_jc_java_lang_reflect_InvocationTargetException$nonrefs;
typedef struct _jc_java_lang_reflect_InvocationTargetException$object	_jc_java_lang_reflect_InvocationTargetException$object;

typedef struct _jc_java_lang_reflect_InvocationTargetException$fields_struct	_jc_java_lang_reflect_InvocationTargetException$fields_struct;
typedef const struct _jc_java_lang_reflect_InvocationTargetException$vmethods	_jc_java_lang_reflect_InvocationTargetException$vmethods;
typedef const struct _jc_java_lang_reflect_InvocationTargetException$vtable	_jc_java_lang_reflect_InvocationTargetException$vtable;
typedef const struct _jc_java_lang_reflect_InvocationTargetException$vtype	_jc_java_lang_reflect_InvocationTargetException$vtype;

// Class fields structure
struct _jc_java_lang_reflect_InvocationTargetException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_reflect_InvocationTargetException$fields_struct _jc_java_lang_reflect_InvocationTargetException$class_fields;

// Constructors
extern void _jc_java_lang_reflect_InvocationTargetException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_reflect_InvocationTargetException$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_reflect_InvocationTargetException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_lang_reflect_InvocationTargetException$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_reflect_InvocationTargetException$method$_init$3ba429d9416edd46(_jc_env *, struct _jc_java_lang_reflect_InvocationTargetException$object *, struct _jc_java_lang_Throwable$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_reflect_InvocationTargetException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_lang_reflect_InvocationTargetException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_reflect_InvocationTargetException$method$getTargetException$53e4eff431eac541(_jc_env *, struct _jc_java_lang_reflect_InvocationTargetException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_reflect_InvocationTargetException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_lang_reflect_InvocationTargetException$method_info$getTargetException$53e4eff431eac541;

// Virtual methods structure
struct _jc_java_lang_reflect_InvocationTargetException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_lang_reflect_InvocationTargetException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Throwable$object	*(*getTargetException$53e4eff431eac541)(_jc_env *, struct _jc_java_lang_reflect_InvocationTargetException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_reflect_InvocationTargetException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_reflect_InvocationTargetException$vmethods	java_lang_reflect_InvocationTargetException;
};

// Vtype
struct _jc_java_lang_reflect_InvocationTargetException$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_InvocationTargetException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_InvocationTargetException$sub_refs {
	struct _jc_java_lang_Throwable$object	*target;
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_InvocationTargetException$refs {
    _jc_java_lang_reflect_InvocationTargetException$sub_refs	java_lang_reflect_InvocationTargetException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_InvocationTargetException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_InvocationTargetException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_reflect_InvocationTargetException$sub_nonrefs	java_lang_reflect_InvocationTargetException;
};

// Object instance structure
struct _jc_java_lang_reflect_InvocationTargetException$object {
	_jc_java_lang_reflect_InvocationTargetException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_InvocationTargetException$vtype	*vtype;
	_jc_java_lang_reflect_InvocationTargetException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_InvocationTargetException$vtype _jc_java_lang_reflect_InvocationTargetException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_InvocationTargetException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_InvocationTargetException$class_object;

#endif	/* _JC_java_lang_reflect_InvocationTargetException_H_ */
